"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _tryit = _interopRequireDefault(require("tryit"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setupGlobalErrorHandlers = ({
  logger,
  extraDataGetter,
  extraCallback
}) => {
  const getExtraData = () => {
    if (!extraDataGetter) {
      return null;
    }

    try {
      return extraDataGetter();
    } catch (e) {
      return null;
    }
  };

  if (typeof globalThis !== 'undefined' && 'addEventListener' in globalThis) {
    globalThis.addEventListener('error', event => {
      let loggerMethod = 'error';
      const {
        message,
        filename,
        lineno,
        colno,
        error
      } = event;
      let errorObject = null;

      if (error) {
        const message = error.message;
        errorObject = {
          message,
          stack: error.stack
        }; // downgrade network errors to "warn" instead of "error"
        // as they are out of our control

        if (message && typeof message === 'string' && message.includes('Network Error')) {
          loggerMethod['warn'];
        }
      }

      logger[loggerMethod]({
        message,
        filename,
        lineno,
        colno,
        errorObject,
        extraData: getExtraData()
      });
      extraCallback && (0, _tryit.default)(() => {
        extraCallback(event);
      });
    });
    globalThis.addEventListener('unhandledrejection', event => {
      logger.error({
        message: 'unhandledRejection',
        event,
        reason: event.reason,
        extraData: getExtraData()
      });
      extraCallback && (0, _tryit.default)(() => {
        extraCallback(event);
      });
    });
  }
};

var _default = setupGlobalErrorHandlers;
exports.default = _default;